#include <stdio.h>
#include <unistd.h>
#include <stdlib.h>
#include <string.h>
#include "version.h"
#include "rmdir.h"

int rmdir_main (int argc, char **argv) {
	char option_recurse=0;
	int i;

	while (1) {
		if ((argc-option_recurse)==1) {
			write(STDERR_FILENO, "rmdir: too few arguments\n", 25);
			return(-1);
		}
		if (!strcmp(argv[1+option_recurse],"-p")) {
			option_recurse++;
		} else {
			break;
		}
	}

	for (i=option_recurse;i<(argc-1);i++) {
/* TODO: Make it actually call rmdir(2) here. */
		printf("%s\n",argv[i]);
	}

	return(0);	
}
